@@ -431,6 +431,9 @@ class CollectionScanner(GObject.GObject, TagReader):
         artists = self.get_artists(tags)
         composers = self.get_composers(tags)
         performers = self.get_performers(tags)
+        remixers = self.get_remixers(tags)
+        if remixers != "":
+            artists += ";%s" % remixers
         a_sortnames = self.get_artist_sortnames(tags)
         aa_sortnames = self.get_album_artist_sortnames(tags)
         album_artists = self.get_album_artists(tags)
