@@ -16,7 +16,7 @@ import itertools
 
 from lollypop.sqlcursor import SqlCursor
 from lollypop.define import App, OrderBy
-from lollypop.utils import noaccents
+from lollypop.utils import noaccents, get_network_available
 
 
 class TracksDatabase:
@@ -393,6 +393,20 @@ class TracksDatabase:
                                   WHERE track_id=?", (track_id,))
             return list(itertools.chain(*result))
 
+    def get_mb_artist_ids(self, track_id):
+        """
+            Get MusicBrainz artist ids
+            @param track id as int
+            @return artist ids as [int]
+        """
+        with SqlCursor(App().db) as sql:
+            result = sql.execute("SELECT mb_artist_id\
+                                  FROM artists, track_artists\
+                                  WHERE track_artists.track_id=?\
+                                  AND track_artists.artist_id=artists.rowid",
+                                 (track_id,))
+            return list(itertools.chain(*result))
+
     def get_artists(self, track_id):
         """
             Get artist names
@@ -468,6 +482,8 @@ class TracksDatabase:
                            album_id=tracks.album_id"
                 if ignore:
                     request += " AND tracks.loved != -1"
+                if not get_network_available("YOUTUBE"):
+                    request += " AND tracks.mtime != -1"
                 request += order
                 result = sql.execute(request)
             # Get albums for genres
@@ -484,6 +500,8 @@ class TracksDatabase:
                 request += "1=0)"
                 if ignore:
                     request += " AND tracks.loved != -1"
+                if not get_network_available("YOUTUBE"):
+                    request += " AND tracks.mtime != -1"
                 request += order
                 result = sql.execute(request, filters)
             # Get albums for artist
@@ -499,6 +517,8 @@ class TracksDatabase:
                 request += "1=0)"
                 if ignore:
                     request += " AND tracks.loved != -1"
+                if not get_network_available("YOUTUBE"):
+                    request += " AND tracks.mtime != -1"
                 request += order
                 result = sql.execute(request, filters)
             # Get albums for artist id and genre id
@@ -520,6 +540,8 @@ class TracksDatabase:
                 request += "1=0)"
                 if ignore:
                     request += " AND tracks.loved != -1"
+                if not get_network_available("YOUTUBE"):
+                    request += " AND tracks.mtime != -1"
                 request += order
                 result = sql.execute(request, filters)
             return list(itertools.chain(*result))
