@@ -12,7 +12,7 @@
 
 from gi.repository import Gio, GLib
 
-from lollypop.define import App
+from lollypop.define import App, ScanType
 from lollypop.utils import is_audio
 from lollypop.logger import Logger
 
@@ -21,15 +21,15 @@ class Inotify:
     """
         Inotify support
     """
-    # 10 second before updating database
-    __TIMEOUT = 10000
+    # 2 seconds before updating database
+    __TIMEOUT = 2000
 
     def __init__(self):
         """
             Init inode notification
         """
         self.__monitors = {}
-        self.__timeout = None
+        self.__timeout_id = None
 
     def add_monitor(self, uri):
         """
@@ -61,7 +61,18 @@ class Inotify:
             @param other_file as Gio.File/None
             @param event as Gio.FileMonitorEvent
         """
-        update = False
+        changed_uri = changed_file.get_uri()
+        # Do not monitor our self
+        if changed_uri in self.__monitors.keys() and\
+                self.__monitors[changed_uri] == monitor:
+            return
+        # Ignore non audio/dir
+        if changed_file.query_exists() and\
+                not is_audio(changed_file) and\
+                changed_file.query_file_type(Gio.FileQueryInfoFlags.NONE,
+                                             None) != Gio.FileType.DIRECTORY:
+            return
+
         # Stop collection scanner and wait
         if App().scanner.is_locked():
             App().scanner.stop()
@@ -73,40 +84,20 @@ class Inotify:
                              event)
         # Run update delayed
         else:
-            uri = changed_file.get_uri()
-            d = Gio.File.new_for_uri(uri)
-            is_dir = False
-            if d.query_exists():
-                # If a directory, monitor it
-                if changed_file.query_file_type(
-                        Gio.FileQueryInfoFlags.NONE,
-                        None) == Gio.FileType.DIRECTORY:
-                    self.add_monitor(uri)
-                    is_dir = True
-                # If not an audio file, exit
-                elif is_audio(changed_file):
-                    update = True
+            if self.__timeout_id is not None:
+                GLib.source_remove(self.__timeout_id)
+            if changed_file.has_parent():
+                uris = [changed_file.get_parent().get_uri()]
             else:
-                update = True
-            if update:
-                if self.__timeout is not None:
-                    GLib.source_remove(self.__timeout)
-                    self.__timeout = None
-                # Launch collection update from this directory
-                # (and not the entire collection)
-                uris = None
-                if is_dir:
-                    uris = [uri]
-                elif changed_file.has_parent():
-                    uris = [changed_file.get_parent().get_uri()]
-                self.__timeout = GLib.timeout_add(self.__TIMEOUT,
-                                                  self.__run_collection_update,
-                                                  uris)
+                uris = [changed_uri]
+            self.__timeout_id = GLib.timeout_add(self.__TIMEOUT,
+                                                 self.__run_collection_update,
+                                                 uris)
 
-    def __run_collection_update(self, uris=None):
+    def __run_collection_update(self, uris=[]):
         """
             Run a collection update
             @param uris as [str]
         """
-        self.__timeout = None
-        App().scanner.update(uris)
+        self.__timeout_id = None
+        App().scanner.update(ScanType.NEW_FILES, uris)
