@@ -34,6 +34,7 @@ class AlbumBannerWidget(Gtk.Bin):
         Gtk.Bin.__init__(self)
         self.__width = 0
         self.__padding = 0
+        art_size = 0
         self.__allocation_timeout_id = None
         self.__album = album
         self.__view_type = view_type
@@ -47,19 +48,32 @@ class AlbumBannerWidget(Gtk.Bin):
         self.__year_label = builder.get_object("year_label")
         self.__duration_label = builder.get_object("duration_label")
         menu_button = builder.get_object("menu_button")
-        if view_type & ViewType.ALBUM and not view_type & ViewType.SMALL:
+        if view_type & ViewType.SMALL:
+            art_size = ArtSize.LARGE
+            icon_size = Gtk.IconSize.BUTTON
+            self.__title_label.get_style_context().add_class(
+                "text-large")
+            self.__year_label.get_style_context().add_class(
+                "text-large")
+            self.__cover_widget = CoverWidget(album, ArtSize.LARGE)
+        elif view_type & ViewType.MEDIUM:
+            art_size = ArtSize.BANNER
+            icon_size = Gtk.IconSize.LARGE_TOOLBAR
+            self.__title_label.get_style_context().add_class(
+                "text-x-large")
+            self.__year_label.get_style_context().add_class(
+                "text-large")
+            self.__cover_widget = CoverWidget(album)
+        else:
+            art_size = ArtSize.BANNER
             icon_size = Gtk.IconSize.LARGE_TOOLBAR
             self.__title_label.get_style_context().add_class(
                 "text-xx-large")
             self.__year_label.get_style_context().add_class(
                 "text-x-large")
-        else:
-            icon_size = Gtk.IconSize.BUTTON
-            if not view_type & ViewType.SMALL:
-                self.__title_label.get_style_context().add_class(
-                    "text-large")
-                self.__year_label.get_style_context().add_class(
-                    "text-large")
+        self.__cover_widget = CoverWidget(album, art_size)
+        self.__cover_widget.set_vexpand(True)
+        self.__cover_widget.show()
         menu_button.get_image().set_from_icon_name("view-more-symbolic",
                                                    icon_size)
         album_name = GLib.markup_escape_text(album.name)
@@ -98,12 +112,6 @@ class AlbumBannerWidget(Gtk.Bin):
             self.__grid.get_style_context().add_class("banner-frame")
             # See application.css: cover-frame
             self.__padding = 8
-        if view_type & ViewType.SMALL or not view_type & ViewType.ALBUM:
-            self.__cover_widget = CoverWidget(album, ArtSize.LARGE)
-        else:
-            self.__cover_widget = CoverWidget(album)
-        self.__cover_widget.set_vexpand(True)
-        self.__cover_widget.show()
         self.__grid.attach(self.__cover_widget, 0, 0, 1, 3)
         self.__rating_grid = builder.get_object("rating_grid")
         if album.mtime <= 0:
@@ -111,22 +119,23 @@ class AlbumBannerWidget(Gtk.Bin):
                                                  icon_size)
             cloud.show()
             cloud.set_margin_start(MARGIN)
-            self.__rating_grid.attach(cloud, 0, 0, 1, 1)
+            self.__rating_grid.attach(cloud, 1, 0, 1, 1)
         rating = RatingWidget(album, icon_size)
         rating.set_property("halign", Gtk.Align.START)
         rating.set_property("valign", Gtk.Align.CENTER)
         rating.show()
-        self.__rating_grid.attach(rating, 1, 0, 1, 1)
+        self.__rating_grid.attach(rating, 2, 0, 1, 1)
         loved = LovedWidget(album, icon_size)
         loved.set_margin_start(10)
         loved.set_property("halign", Gtk.Align.START)
         loved.set_property("valign", Gtk.Align.CENTER)
         loved.show()
-        self.__rating_grid.attach(loved, 2, 0, 1, 1)
+        self.__rating_grid.attach(loved, 3, 0, 1, 1)
         self.add(self.__widget)
         self.__cover_widget.set_margin_start(MARGIN)
         self.__year_label.set_margin_end(MARGIN)
-        self.__duration_label.set_margin_end(MARGIN)
+        self.__duration_label.set_margin_start(MARGIN)
+        self.__rating_grid.set_margin_end(MARGIN)
 
     def set_height(self, height):
         """
@@ -142,7 +151,10 @@ class AlbumBannerWidget(Gtk.Bin):
             self.__duration_label.hide()
             self.__rating_grid.hide()
             self.__year_label.set_vexpand(True)
-            if not self.__view_type & ViewType.SMALL:
+            if self.__view_type & ViewType.SMALL:
+                self.__title_label.get_style_context().remove_class(
+                    "text-large")
+            else:
                 self.__title_label.get_style_context().remove_class(
                     "text-xx-large")
                 self.__title_label.get_style_context().add_class(
@@ -159,7 +171,10 @@ class AlbumBannerWidget(Gtk.Bin):
             self.__duration_label.show()
             self.__rating_grid.show()
             self.__year_label.set_vexpand(False)
-            if not self.__view_type & ViewType.SMALL:
+            if self.__view_type & ViewType.SMALL:
+                self.__title_label.get_style_context().add_class(
+                    "text-large")
+            else:
                 self.__title_label.get_style_context().remove_class(
                     "text-x-large")
                 self.__title_label.get_style_context().add_class(
@@ -204,11 +219,12 @@ class AlbumBannerWidget(Gtk.Bin):
         """
             Get default height
         """
-        if self.__view_type & ViewType.ALBUM and\
-                not self.__view_type & ViewType.SMALL:
-            return ArtSize.BANNER + 40
-        else:
+        if self.__view_type & ViewType.SMALL:
             return ArtSize.LARGE + 20
+        elif self.__view_type & ViewType.MEDIUM:
+            return ArtSize.BANNER + 20
+        else:
+            return ArtSize.BANNER + 40
 
 #######################
 # PROTECTED           #
